@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from cleo.exceptions import LogicException
+from cleo.exceptions import CleoLogicError
 from cleo.loaders.factory_command_loader import FactoryCommandLoader
 
 
@@ -12,11 +12,11 @@ if TYPE_CHECKING:
     from poetry.console.commands.command import Command
 
 
-class CommandLoader(FactoryCommandLoader):  # type: ignore[misc]
+class CommandLoader(FactoryCommandLoader):
     def register_factory(
         self, command_name: str, factory: Callable[[], Command]
     ) -> None:
         if command_name in self._factories:
-            raise LogicException(f'The command "{command_name}" already exists.')
+            raise CleoLogicError(f'The command "{command_name}" already exists.')
 
         self._factories[command_name] = factory
