@@ -166,7 +166,7 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
                 self._determine_requirements(self.option("dependency"))
             )
 
-        question = "Would you like to define your main dependencies interactively?"
+        question_text = "Would you like to define your main dependencies interactively?"
         help_message = """\
 You can specify a package in the following forms:
   - A single name (<b>requests</b>): this will search for matches on PyPI
@@ -180,7 +180,7 @@ You can specify a package in the following forms:
 """
 
         help_displayed = False
-        if self.confirm(question, True):
+        if self.confirm(question_text, True):
             if self.io.is_interactive():
                 self.line(help_message)
                 help_displayed = True
@@ -196,10 +196,10 @@ You can specify a package in the following forms:
                 self._determine_requirements(self.option("dev-dependency"))
             )
 
-        question = (
+        question_text = (
             "Would you like to define your development dependencies interactively?"
         )
-        if self.confirm(question, True):
+        if self.confirm(question_text, True):
             if self.io.is_interactive() and not help_displayed:
                 self.line(help_message)
 
@@ -328,8 +328,8 @@ You can specify a package in the following forms:
                         "Enter the version constraint to require "
                         "(or leave blank to use the latest version):"
                     )
-                    question.attempts = 3
-                    question.validator = lambda x: (x or "").strip() or False
+                    question.set_max_attempts(3)
+                    question.set_validator(lambda x: (x or "").strip() or None)
 
                     package_constraint = self.ask(question)
 
